==> haskell-microlens-ghc-0.4.13-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-microlens-ghc.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 microlens-ghc
version:              0.4.13
visibility:           public
id:                   microlens-ghc-0.4.13-48zqf4CXAJT1iw1DYvoq9p
key:                  microlens-ghc-0.4.13-48zqf4CXAJT1iw1DYvoq9p
license:              BSD-3-Clause
maintainer:           Monadfix <hi@monadfix.com>
author:               Edward Kmett, Artyom Kazak
homepage:             http://github.com/monadfix/microlens
synopsis:             microlens + array, bytestring, containers, transformers
description:
    Use this package instead of <http://hackage.haskell.org/package/microlens microlens> if you don'\''t mind depending on all dependencies here – @Lens.Micro.GHC@ reexports everything from @Lens.Micro@ and additionally provides orphan instances of microlens classes for packages coming with GHC (<http://hackage.haskell.org/package/array array>, <http://hackage.haskell.org/package/bytestring bytestring>, <http://hackage.haskell.org/package/containers containers>, <http://hackage.haskell.org/package/transfromers transformers>).

    The minor and major versions of microlens-ghc are incremented whenever the minor and major versions of microlens are incremented, so you can depend on the exact version of microlens-ghc without specifying the version of microlens you need.

    This package is a part of the <http://hackage.haskell.org/package/microlens microlens> family; see the readme <https://github.com/monadfix/microlens#readme on Github>.

category:             Data, Lenses
abi:                  a02b677eb317d7d6fbcac818e6916557
exposed:              True
exposed-modules:      Lens.Micro.GHC Lens.Micro.GHC.Internal
import-dirs:          /usr/lib/ghc-8.10.5/site-local/microlens-ghc-0.4.13
library-dirs:         /usr/lib/ghc-8.10.5/site-local/microlens-ghc-0.4.13
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.5/microlens-ghc-0.4.13
hs-libraries:         HSmicrolens-ghc-0.4.13-48zqf4CXAJT1iw1DYvoq9p
depends:
    array-0.5.4.0 base-4.14.2.0 bytestring-0.10.12.0 containers-0.6.4.1
    microlens-0.4.12.0-7mbtYeVEJj9DE2AV66WaoK transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-microlens-ghc/html/microlens-ghc.haddock

haddock-html:         /usr/share/doc/haskell-microlens-ghc/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-microlens-ghc-0.4.14.0-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-microlens-ghc.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 microlens-ghc
version:              0.4.14.0
visibility:           public
id:                   microlens-ghc-0.4.14.0-4LuJtgitHQH8Ol1dUlZ5bR
key:                  microlens-ghc-0.4.14.0-4LuJtgitHQH8Ol1dUlZ5bR
license:              BSD-3-Clause
maintainer:           Steven Fontanella <steven.fontanella@gmail.com>
author:               Edward Kmett, Artyom Kazak
homepage:             http://github.com/monadfix/microlens
synopsis:             microlens + array, bytestring, containers, transformers
description:
    Use this package instead of <http://hackage.haskell.org/package/microlens microlens> if you don'\''t mind depending on all dependencies here – @Lens.Micro.GHC@ reexports everything from @Lens.Micro@ and additionally provides orphan instances of microlens classes for packages coming with GHC (<http://hackage.haskell.org/package/array array>, <http://hackage.haskell.org/package/bytestring bytestring>, <http://hackage.haskell.org/package/containers containers>, <http://hackage.haskell.org/package/transfromers transformers>).

    The minor and major versions of microlens-ghc are incremented whenever the minor and major versions of microlens are incremented, so you can depend on the exact version of microlens-ghc without specifying the version of microlens you need.

    This package is a part of the <http://hackage.haskell.org/package/microlens microlens> family; see the readme <https://github.com/monadfix/microlens#readme on Github>.

category:             Data, Lenses
abi:                  7ac1b887c89d6f935c45f5af312038db
exposed:              True
exposed-modules:      Lens.Micro.GHC Lens.Micro.GHC.Internal
import-dirs:          /usr/lib/ghc-9.0.2/site-local/microlens-ghc-0.4.14.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/microlens-ghc-0.4.14.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-microlens-ghc
hs-libraries:         HSmicrolens-ghc-0.4.14.0-4LuJtgitHQH8Ol1dUlZ5bR
depends:
    array-0.5.4.0 base-4.15.1.0 bytestring-0.10.12.1 containers-0.6.4.1
    microlens-0.4.13.0-8kbZITwqGed8vNsPXOVOwI transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-microlens-ghc/html/microlens-ghc.haddock

haddock-html:         /usr/share/doc/haskell-microlens-ghc/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
